==> rlstack-0.1.2.tar.gz: rlstack-0.1.2/examples/algotrading/__main__.py <==
import argparse

import mlflow
import torch

from rlstack import Algorithm, RecurrentAlgorithm, Trainer
from rlstack.conditions import Plateaus

from .env import AlgoTrading
from .models import AttentiveAlpaca, LazyLemur, MischievousMule

if __name__ == "__main__":
    parser = argparse.ArgumentParser(
        description=(
            "An example algotrading environment where a policy learns to hold, buy, and"
            " sell an asset. This example serves as a playground for custom,"
            " sequence-based and recurrent models."
        )
    )
    parser.add_argument(
        "--model",
        choices=["lstm", "mlp", "transformer"],
        default="mlp",
        help="Model class type to use.",
    )
    args = parser.parse_args()

    match args.model:
        case "lstm":
            algorithm_cls = RecurrentAlgorithm
            model_cls = LazyLemur
        case "mlp":
            algorithm_cls = Algorithm
            model_cls = MischievousMule
        case "transformer":
            algorithm_cls = Algorithm
            model_cls = AttentiveAlpaca

    experiment = mlflow.set_experiment("rlstack.examples.algotrading")
    print(f"Logging run under MLFlow experiment {experiment.experiment_id}")
    trainer = Trainer(
        AlgoTrading,
        algorithm_cls=algorithm_cls,
        algorithm_config={
            "model_cls": model_cls,
            "enable_amp": torch.cuda.is_available(),
            "device": "cuda" if torch.cuda.is_available() else "cpu",
        },
        stop_conditions=[Plateaus("returns/mean", patience=10, rtol=0.05)],
    )
    run = mlflow.active_run()
    print(f"Logging metrics under MLFlow run {run.info.run_id}")
    trainer.run()

==> rlstack-1.0.1.tar.gz: rlstack-1.0.1/examples/algotrading/__main__.py <==
import argparse

import mlflow
import torch

from rlstack import RecurrentTrainer, Trainer
from rlstack.conditions import Plateaus

from .env import AlgoTrading
from .models import AttentiveAlpaca, LazyLemur, MischievousMule

if __name__ == "__main__":
    parser = argparse.ArgumentParser(
        description=(
            "An example algotrading environment where a policy learns to hold, buy, and"
            " sell an asset. This example serves as a playground for custom,"
            " sequence-based and recurrent models."
        )
    )
    parser.add_argument(
        "--model",
        choices=["lstm", "mlp", "transformer"],
        default="mlp",
        help="Model class type to use.",
    )
    args = parser.parse_args()

    match args.model:
        case "lstm":
            trainer_cls = RecurrentTrainer
            model_cls = LazyLemur
        case "mlp":
            trainer_cls = Trainer
            model_cls = MischievousMule
        case "transformer":
            trainer_cls = Trainer
            model_cls = AttentiveAlpaca

    experiment = mlflow.set_experiment("rlstack.examples.algotrading")
    print(f"Logging run under MLflow experiment {experiment.experiment_id}")
    trainer = trainer_cls(
        AlgoTrading,
        model_cls=model_cls,
        enable_amp=torch.cuda.is_available(),
        device="cuda" if torch.cuda.is_available() else "cpu",
    )
    run = mlflow.active_run()
    print(f"Logging metrics under MLflow run {run.info.run_id}")
    trainer.run(
        steps_per_eval=10,
        stop_conditions=[Plateaus("returns/mean", patience=10, rtol=0.05)],
    )
